
import ezcfglib.df.*;
import ezcfglib.lib.*;

import java.net.*;
import java.io.*;

public class EzcfglibTest {
	
	private EzcfgLib ezcfglib;
	private int EztcpCnt;
	
	public int getEztcpCnt() {
		return EztcpCnt;
	}

	public void setEztcpCnt(int eztcpCnt) {
		EztcpCnt = eztcpCnt;
	}

	public EzcfglibTest() {
		EztcpCnt = 0;
		ezcfglib = new EzcfgLib();
	}
	
	public void GetVersion() {
		System.out.println(ezcfglib.GetLibVerEzTCP());
	}
	
	public void SearchEzTCP(Spe_Env []env, Wlan_Env[] wenv, Etc_Opt[] etc)
		throws Exception {
		Res_Env res = new Res_Env();
		
		try {
			ezcfglib.ProbeEzTCP(env, wenv, etc, res);
		} catch ( Exception e ) {
			System.out.println("Probe Error:");
			e.printStackTrace();
		}
		
		if ( res.getErr() == Common.EZTCP_ERR_RES ) {
			setEztcpCnt(0);
		} else {
			setEztcpCnt(res.getResultCount());
			
			for ( int i = 0 ; i < getEztcpCnt() ; i++ ) {
				InetAddress addr = InetAddress.getByAddress(Common.BigInt2BigByte(env[i].getLocal_ip()));
				byte mac[] = env[i].getEth_addr();
				String str = String.format("[No %d] %02X:%02X:%02X:%02X:%02X:%02X \tIP=%s", 
											i+1, 
											mac[0],
											mac[1],
											mac[2],
											mac[3],
											mac[4],
											mac[5],
											addr.getHostAddress());
				System.out.println(str);
				
				if ( mac[3] == 0x02 ) {
					ezcfglib.WriteEzTCP(env[i], wenv[i], etc[i], res);
				}
			}
		}
	}
	
	public void RemoteSearchEzTCP(Spe_Env []env, Wlan_Env[] wenv, Etc_Opt[] etc)
		throws Exception {
	Res_Env res = new Res_Env();
	InetAddress addr;
	
	try {
		addr = InetAddress.getByAddress(Common.BigInt2BigByte(Common.MK_IP(10, 1, 0, 1)));
		ezcfglib.RemoteReadEzTCP(addr, env, wenv, etc, res);
	} catch ( Exception e ) {
		System.out.println("Remote read Error:");
		e.printStackTrace();
	}
	
	if ( res.getErr() == Common.EZTCP_ERR_RES ) {
		setEztcpCnt(0);
	} else {
		setEztcpCnt(res.getResultCount());
		
		for ( int i = 0 ; i < getEztcpCnt() ; i++ ) {
			InetAddress addr1 = InetAddress.getByAddress(Common.BigInt2BigByte(env[i].getLocal_ip()));
			byte mac[] = env[i].getEth_addr();
			String str = String.format("[No %d] %02X:%02X:%02X:%02X:%02X:%02X \tIP=%s", 
										i+1, 
										mac[0],
										mac[1],
										mac[2],
										mac[3],
										mac[4],
										mac[5],
										addr1.getHostAddress());
			System.out.println(str);
		}
	}
}
	public void StatusTest(int where, Spe_Env env) {
		Res_Env res 	= new Res_Env();
		Stat_Env stat 	= new Stat_Env();
		String str;
		
		try {
			if ( where == EzcfgLib.BROADCAST )
				ezcfglib.StatusEzTCP(env, stat, res);
			else if ( where == EzcfgLib.UNICAST ) {
				InetAddress addr = InetAddress.getByAddress(Common.BigInt2BigByte(env.getLocal_ip()));
				ezcfglib.RemoteStatusEzTCP(addr, env, stat, res);
			}
			
			if ( res.getErr() != Common.EZTCP_ERR_RES ){
				System.out.println("Firmware Version : "+stat.getVer());
				System.out.println("Frequency : "+stat.getFreq());
				System.out.println("Uptime : "+stat.getUptime());
				System.out.println("MAC address : " + stat.getMac_addr());
				System.out.println("IP address : " + stat.getIp_addr());
				System.out.println("Subnet Mask : " + stat.getSub_mask());
				System.out.println("Gateway : " + stat.getGate_addr());
				
				str = String.format("%d", stat.getSio_rx());
				System.out.println("Serial RX bytes : "+str);
				
				str = String.format("%d", stat.getSio_tx());
				System.out.println("Serial TX bytes : "+str);
				
				str = String.format("%d", stat.getEth_rx());
				System.out.println("LAN RX bytes : "+str);
				
				str = String.format("%d", stat.getEth_tx());
				System.out.println("LAN TX bytes : "+str);
				
				System.out.println("==========================");
				System.out.println(stat.getText());
				System.out.println("==========================");
			}
			
		} catch ( Exception e ) {
			e.printStackTrace();
		}
	}
	
	public void WriteTest(int where, Spe_Env env, Wlan_Env wenv, Etc_Opt etc, String pwd) {
		Spe_Env 	temp_env 	= env;
		Wlan_Env 	temp_wenv 	= wenv;
		Etc_Opt 	temp_etc 	= etc;
		Res_Env 	res 		= new Res_Env();
		
		int local_ip = temp_env.getLocal_ip();
		
		byte[] byte_pwd = pwd.getBytes();
		String str = "ѱ ڸƮ.";
		
		temp_env.setArp(false);
		temp_env.setRemoteConfig(true);
		temp_env.setMux_type((byte)Common.MUX_TYPE_T2S);
		
		temp_env.setLocal_port((short)50000);
		
		temp_env.setTimeout((short)100);
		
		temp_env.setSio_baud(9600);
		temp_env.setParity(2);
		
		temp_env.setRtsCts(true);
		
		byte[] comment = str.getBytes();
		if ( comment.length > 32 ) {
			System.out.println("Comments is too long");
			return;
		}
		temp_etc.setComment(comment);
		
		if ( byte_pwd.length > 0 ) {
			if ( byte_pwd.length > 8 ) {
				System.out.println("password is too long");
				return;
			} else {
				temp_env.setPasswd(byte_pwd);
			}
		}
		
		//=================================================
		// WLAN setting..
//		// Access Point Environment value.
		// ESS-ID  : ovis
		// WEP     : Use.
		// WEP ID  : 1.
		// WEP KEY : Enter 0123456789 in HEX mode.
		temp_wenv.setCCType(1); 	/* 0 : adhoc, 1 : infrastructure */
		temp_wenv.setChannel(11); 	/* AP's channel */
		temp_wenv.setWep(1);		/* 0 : no-wep, 1 - 64 bits, 2 - 128 bits */
		temp_wenv.setWepId(0);		/* index of WEP ID in AP. 
		  								- The index start from 0(zero) in ezConfig library.*/
		temp_wenv.setStartAdhoc(true);	/* see the manual for more information */
		temp_wenv.setStartIfs(true);	/* see the manual for more information */
		
		String ssid = "ovis";
		temp_wenv.setTarget_ssid(ssid.getBytes());
		
		byte key64[][] = temp_wenv.getKey64();
		key64[temp_wenv.getWepId()][0] = (byte)0x01;
		key64[temp_wenv.getWepId()][1] = (byte)0x23;
		key64[temp_wenv.getWepId()][2] = (byte)0x45;
		key64[temp_wenv.getWepId()][3] = (byte)0x67;
		key64[temp_wenv.getWepId()][4] = (byte)0x89;
		//=================================================
		
		try {
			if ( where == EzcfgLib.BROADCAST )
				ezcfglib.WriteEzTCP(temp_env, temp_wenv, temp_etc, res);
			else if ( where == EzcfgLib.UNICAST ) {
				InetAddress addr = InetAddress.getByAddress(Common.BigInt2BigByte(local_ip));
				ezcfglib.RemoteWriteEzTCP(addr, temp_env, temp_wenv, temp_etc, res);
			}
			
			if ( res.getErr() == Common.EZTCP_NO_ERR ) {
				System.out.println("Write Success");
			} else if ( res.getErr() == Common.EZTCP_ERR_PWD ) {
				System.out.println("Password mismatch error...");
			} else if ( res.getErr() == Common.EZTCP_ERR_RES ) {
				System.out.println("Write Error...");
			} else {
				System.out.println("Unknown error...");
			}
			
		} catch ( Exception e ) {
			e.printStackTrace();
		}
		
	}
	
	public void PasswordTest(int where, Spe_Env env, int set_or_change_or_clear, String pwd, String new_pwd) {
		String ChangePwd = "";
		Res_Env res = new Res_Env();
		
		if ( set_or_change_or_clear == 1 ) { // set password
			ChangePwd = pwd;
		} else if ( set_or_change_or_clear == 2 ) { // change password
			env.setPasswd(pwd.getBytes());
			ChangePwd = new_pwd;
		} else if ( set_or_change_or_clear == 3 ) { // clear password
			env.setPasswd(pwd.getBytes());
			ChangePwd = "";
		}
		
		try {
			if ( where == EzcfgLib.BROADCAST )
				ezcfglib.ChangePwdEzTCP(env, ChangePwd, res);
			else if ( where == EzcfgLib.UNICAST ) {
				InetAddress addr = InetAddress.getByAddress(Common.BigInt2BigByte(env.getLocal_ip()));
				ezcfglib.RemoteChangePwdEzTCP(addr, env, ChangePwd, res);
			}
			
			if ( res.getErr() == Common.EZTCP_NO_ERR ) {
				System.out.println("Password write Success");
			} else if ( res.getErr() == Common.EZTCP_ERR_PWD ) {
				System.out.println("Password mismatch error...");
			} else if ( res.getErr() == Common.EZTCP_ERR_RES ) {
				System.out.println("Password write Error...");
			} else {
				System.out.println("Unknown error...");
			}
		} catch ( Exception e ) {
			e.printStackTrace();
		}
	}
	
	public void CloseTCPTest(int where, Spe_Env env, String pwd)
	{
		Res_Env res = new Res_Env();
		try {
			if ( where == EzcfgLib.BROADCAST )
				ezcfglib.CloseTCP(env, pwd, res);
			else if ( where == EzcfgLib.UNICAST ) {
				InetAddress addr = InetAddress.getByAddress(Common.BigInt2BigByte(env.getLocal_ip()));
				ezcfglib.RemoteCloseTCP(addr, env, pwd, res);
			}
			
			if ( res.getErr() == Common.EZTCP_NO_ERR ) {
				System.out.println("close tcp Success");
			} else if ( res.getErr() == Common.EZTCP_ERR_PWD ) {
				System.out.println("Password mismatch error...");
			} else if ( res.getErr() == Common.EZTCP_ERR_RES ) {
				System.out.println("close tcp Error...");
			} else {
				System.out.println("Unknown error...");
			}
		} catch ( Exception e ) {
			e.printStackTrace();
		}
	}
	
	public void ResetEzTCPTest(int where, Spe_Env env, String pwd)
	{
		Res_Env res = new Res_Env();
		try {
			if ( where == EzcfgLib.BROADCAST )
				ezcfglib.ResetEzTCP(env, pwd, res);
			else if ( where == EzcfgLib.UNICAST ) {
				InetAddress addr = InetAddress.getByAddress(Common.BigInt2BigByte(env.getLocal_ip()));
				ezcfglib.RemoteResetEzTCP(addr, env, pwd, res);
			}
			
			if ( res.getErr() == Common.EZTCP_NO_ERR ) {
				System.out.println("reset Success");
			} else if ( res.getErr() == Common.EZTCP_ERR_PWD ) {
				System.out.println("Password mismatch error...");
			} else if ( res.getErr() == Common.EZTCP_ERR_RES ) {
				System.out.println("reset Error...");
			} else {
				System.out.println("Unknown error...");
			}
		} catch ( Exception e ) {
			e.printStackTrace();
		}
	}
	
	public static void main(String[] args) {
		int eztcp_cnt = 0;
		Spe_Env env[] 	= new Spe_Env[256];
		Wlan_Env wlan[] = new Wlan_Env[256];
		Etc_Opt opt[] 	= new Etc_Opt[256];
		String pwd = "", new_pwd = "";
				
		EzcfglibTest test = new EzcfglibTest();
		
		test.GetVersion();
		
		try {
			/* Local Search */
			//test.SearchEzTCP(env, wlan, opt);
			
			/* Remote Search */
			test.RemoteSearchEzTCP(env, wlan, opt);
			
			eztcp_cnt = test.getEztcpCnt();
			
			if ( eztcp_cnt > 0 ) {
				for ( int i = 0 ; i < eztcp_cnt ; i++ ) {
					byte mac[] = env[i].getEth_addr();
					
					if ( (mac[3]&0xFF) == 0x01 && (mac[4]&0xFF) == 0x63 && (mac[5]&0xFF) == 0xe6 ) {
						String comments = new String(opt[i].getComment());
						System.out.println("Comments : "+comments);
						
						System.out.println("TX Delay: "+env[i].getTxDelay());
						/* Status Test */
						//test.StatusTest(EzcfgLib.BROADCAST, env[i]);
						//test.StatusTest(EzcfgLib.UNICAST, env[i]);
						
						/* Write Test */
						/* Local */
						env[i].setTxDelay(true);
						pwd = "1111";
						//test.WriteTest(EzcfgLib.BROADCAST, env[i], wlan[i], opt[i], pwd);
						//test.WriteTest(EzcfgLib.UNICAST, env[i], wlan[i], opt[i], pwd);
						
						/* set password */
						// maximum password length is 8bytes.
						//pwd = "01234567";
						/* Local */
						//test.PasswordTest(EzcfgLib.BROADCAST, env[i], 1, pwd, new_pwd);
						/* Remote */
						//test.PasswordTest(EzcfgLib.UNICAST, env[i], 1, pwd, new_pwd);
						
						/* change password */
						//pwd = "01234567";
						//new_pwd = "abcdefgh";
						/* Local */
						//test.PasswordTest(EzcfgLib.BROADCAST, env[i], 2, pwd, new_pwd);
						/* Remote */
						//test.PasswordTest(EzcfgLib.UNICAST, env[i], 2, pwd, new_pwd);
						
						/* clear password */
						//pwd 	= "abcdefgh";
						//new_pwd = "";
						/* Local */
						//test.PasswordTest(EzcfgLib.BROADCAST, env[i], 3, pwd, new_pwd);
						/* Remote */
						//test.PasswordTest(EzcfgLib.UNICAST, env[i], 3, pwd, new_pwd);
						
						/* Close TCP */
						//test.CloseTCPTest(EzcfgLib.BROADCAST, env[i], pwd);
						//test.CloseTCPTest(EzcfgLib.UNICAST, env[i], pwd);
						
						/* Reset EzTCP */
						//test.ResetEzTCPTest(EzcfgLib.BROADCAST, env[i], pwd);
						//test.ResetEzTCPTest(EzcfgLib.UNICAST, env[i], pwd);
					}
				}
			}
			
		} catch (Exception e) {
			e.printStackTrace();
		}
	}
}
